@@ -128,6 +128,7 @@ void MessageListWindow::createMenus()
     
     QMenu* mailboxMenu = menubar->addMenu( tr("Mailbox") );
     mailboxMenu->addAction( resyncMbox );
+    mailboxMenu->addAction( expunge );
 }
 
 void MessageListWindow::createWidgets()
@@ -222,9 +223,6 @@ void MessageListWindow::msgListSelectionChanged( const QItemSelection& selected,
 
 void MessageListWindow::msgListClicked( const QModelIndex& index )
 {
-    Q_ASSERT( index.isValid() );
-    Q_ASSERT( index.model() == msgListModel );
-
     // cleanup previous window
     if(messageWindow) {
         messageWindow->disconnect();
